startPreview method
Enables the local video preview. This method starts the local video preview before joining the channel. Before calling this method, ensure that you do the following: Call enableVideo to enable the video. The local preview enables the mirror mode by default. After the local video preview is enabled, if you call leaveChannel to exit the channel, the local preview remains until you call stopPreview to disable it.
Implementation
Future<void> startPreview() async {
await _engine!.startPreview();
}