PubLiveRemoteView class

SurfaceView class for rendering remote video. Extends from the RtcSurfaceView class. This class has the following corresponding classes: Android: SurfaceView (https://developer.android.com/reference/android/view/SurfaceView). iOS: UIView (https://developer.apple.com/documentation/uikit/uiview) Applies to the macOS and Windows platforms only.

Constructors

PubLiveRemoteView()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getPubLiveRemoteSurfaceView({Key? key, required int uid, required String channelId, VideoRenderMode renderMode = VideoRenderMode.Hidden, VideoMirrorMode mirrorMode = VideoMirrorMode.Auto, bool zOrderOnTop = false, bool zOrderMediaOverlay = false, PlatformViewCreatedCallback? onPlatformViewCreated, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers}) → SurfaceView
getPubLiveRemoteTextureView({Key? key, required int uid, required String channelId, VideoRenderMode renderMode = VideoRenderMode.Hidden, VideoMirrorMode mirrorMode = VideoMirrorMode.Auto, PlatformViewCreatedCallback? onPlatformViewCreated, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers, bool useFlutterTexture = true}) → TextureView