ChatManager class
Constructors
- ChatManager()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAccount(
String username, String password) → Future< void> - Register a new user.
-
createTxtSendMessage(
{required String username, required String content}) → EMMessage - Creates a text message for sending.
-
login(
String username, String pwdOrToken, [bool isPassword = true]) → Future< void> - An app user logs in to the chat server with a password or token.
-
logout(
[bool unbindDeviceToken = true]) → Future< void> - An app user logs out.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
EMMessage message) → Future< EMMessage> - Sends a message.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- messageManager → ChatMessageManager
-
final